@@ -109,7 +109,10 @@ class IntegerField(Field):
 class PositiveIntegerField(IntegerField):
     pass
 
-class ForeignKey(Field):
+class RelField(Field):
+    pass
+
+class ForeignKey(RelField):
 
     def from_raw(self, data):
         if data is not None:
@@ -123,7 +126,11 @@ class ForeignKey(Field):
         return unicode(data)
 
     def to_raw(self, data):
-        return data.id
+        try:
+            return data.id
+        except AttributeError:
+            return None
+
 
     def __init__(self, model, verbose_name=None, *args, **kwargs):
         super(ForeignKey, self).__init__(verbose_name=verbose_name, *args, **kwargs)
@@ -187,7 +194,11 @@ class Model(object):
     read_only_fields = []
     """@cvar: List of fields to read-only"""
 
+    include_methods_results = {}
+    """@cvar: Dict of methods to fetch from server"""
 
+    dump_order = 0
+    """@cvar: Order to dump"""
 
     @classmethod
     def load(cls):
@@ -227,7 +238,10 @@ class Model(object):
         for method in cls.exclude_methods:
             setattr(cls, method, getattr(Model, method))
 
-        for field in cls.read_only_fields:
+        for method in cls.include_methods_results:
+            setattr(cls, method, cls.include_methods_results[method])
+
+        for field in cls.read_only_fields+cls.include_methods_results.keys():
             getattr(cls, field).read_only = True
 
     @classmethod
@@ -247,11 +261,8 @@ class Model(object):
                     responces.append(resp)
                     if resp["headers"]["status"]=="200":
                         body = json.loads(resp["body"])
-                        cls.objects.remove(o)
-                        del o
-                        newo = cls(**body)
-                        newo.__dumped=True
-                        cls.objects.append(newo)
+                        o.__refresh(**body)
+                        o.__dumped=True
                     elif resp["headers"]["status"]=="400":
                         o.__valid = False
 
@@ -263,8 +274,10 @@ class Model(object):
         """Returns raw model instance representation"""
         d = {}
         for fieldname, field in self.__class__.get_fields().items():
-            if fieldname!="id" and not field.read_only:
+            if fieldname!="id" and not field.read_only and getattr(self, fieldname) is not None:
                 d[fieldname]=unicode(field.to_raw(getattr(self, fieldname))).encode('utf-8')
+        from pprint import pprint
+        pprint(d)
         return d
 
     @classmethod
@@ -278,6 +291,7 @@ class Model(object):
         o.__dumped = False
         o.id = cls.max_negative_undumped_id
         cls.max_negative_undumped_id-=1
+        cls.objects.append(o)
         return o
 
     @classmethod
@@ -324,6 +338,46 @@ class Model(object):
                 f[fieldname] = getattr(cls, fieldname)
         return f
 
+    @classmethod
+    def get_rel_fields(cls):
+        """
+        Returns dict of relative (Foreign keys, etc) Fields
+        """
+        f = {}
+        for fieldname in dir(cls):
+            field = getattr(cls, fieldname)
+            try:
+                if RelField in getmro(field.__class__):
+                    f[fieldname] = getattr(cls, fieldname)
+            except AttributeError:
+                pass
+
+        return f
+
+
+
+    @staticmethod
+    def is_model_depend_on(one_class, other_class):
+        """
+        Returns True, if class has references to another class
+        """
+#        print one_class , "<=>" , other_class
+        for field in one_class.get_rel_fields().values():
+            if field.model==other_class:
+#                print one_class , "depend on" , other_class
+                return 1
+        return -1
+
+    @staticmethod
+    def is_model_instance_depend_on(model_instance, other_model_instance):
+        """
+        Returns True, if model instance has references to another class
+        """
+        for fieldname, field in model_instance.get_rel_fields().items():
+            if getattr(model_instance, fieldname)==other_model_instance:
+                return 1
+        return -1
+
     def is_filtered(self, **kwargs):
         for field in kwargs:
             try:
@@ -333,13 +387,19 @@ class Model(object):
                 except TypeError:
                     if not getattr(self, field)==kwargs[field]:
                         return False
-            except KeyError:
+            except AttributeError:
+                #FIXME to any number of folding
                 if "__" in field:
-                    keymodel, keyfield = field.split("__")
-                    if getattr(getattr(self,keymodel),keyfield)!=kwargs[field]:
-                        return False
+                    try:
+                        keymodel, keyfield = field.split("__")
+                        if getattr(getattr(self,keymodel),keyfield)!=kwargs[field]:
+                            return False
+                    except ValueError:
+                        keymodel, keyfield, keyfield2 = field.split("__")
+                        if getattr(getattr(getattr(self,keymodel),keyfield),keyfield2)!=kwargs[field]:
+                            return False
                 else:
-#                    print field
+                    print field, self
                     raise KeyError
         return True
 
@@ -372,6 +432,10 @@ class Model(object):
 #        print initdict
         self.__valid = True
         """@ivar __valid: False if model instance failed validation"""
+        self.__refresh(**initdict)
+
+    def __refresh(self, **initdict):
+        self.__valid = True
         for fieldname, field in self.__class__.get_fields().items():
             try:
                 setattr(self, fieldname, field.from_raw(initdict[fieldname]))
@@ -379,9 +443,6 @@ class Model(object):
                 setattr(self, fieldname, field.blank())
 
 
-    def validate(self):
-        return True
-
     @classmethod
     def notify(cls):
         """Sends notify to all views, connected to model"""
@@ -394,12 +455,9 @@ class Model(object):
         """
         Saves object
         """
-        if self.validate():
-            dubl = self.get(self.id)
-            if dubl is None:
-                self.objects.append(self)
-            self.__dumped = False
-            self.notify()
+
+        self.__dumped = False
+        self.notify()
 
     @classmethod
     def add_notify(cls, view):
